==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-datatable.dart <==
import 'package:flutter/material.dart';
import 'theme.dart';
import 'widget-classesUsed.dart';


/*
Imports required:
import 'custom-datatable.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';

This widget is used to display a Data Table.
    The view comprises datarows, datacolumns, which in turn comprise of datacells.
    This is a stateless widget.
    The user specifies the headers in the data column, and the data in the datarows.

    SAMPLE IMPLEMENTATION:
    RowColumn row1=new RowColumn(["Ganguly", "38", "Cricketer"]);
    RowColumn row2=new RowColumn(["Messi", "32", "Footballer"]);
    List<RowColumn> rows=[];
    rows.add(row1);
    rows.add(row2);
    RowColumn column = new RowColumn(["name", "age", "Work"]);
    DataTableSchema dt=new DataTableSchema(columns:column,rows:rows, backgroundColour:Colors.white,rowtextColour: Colors.black, rowtextSize: 12.0, columntextColour: Colors.blueAccent,columntextSize: 14.0);


    //implementation
    Center(child: CustomisedDataTable(dt))

    */

//AUTHOR : Soumyadeep Mitra

//WIDGET FOR DATA TABLE
Widget CustomisedDataTable(DataTableSchema dataTable) {
  List<DataRow> r = [];
  List<DataCell> dc = [];
  List<DataColumn> c = [];

  for (var value in dataTable.columns.rowcolumn)
    c.add(DataColumn(
      label: Text(
        value,
        style: TextStyle(fontStyle: FontStyle.italic,color: dataTable.columntextColour==null?MediumGreyThemeData().hintColor:dataTable.columntextColour, fontSize:dataTable.columntextSize==null?12.0:dataTable.columntextSize ),
      ),
    ));

  for (var value in dataTable.rows) {
    dc = [];
    for (var value1 in value.rowcolumn) {
      dc.add(DataCell(Text(value1,style: TextStyle(fontStyle: FontStyle.italic,color: dataTable.rowtextColour==null?MediumGreyThemeData().hintColor:dataTable.rowtextColour,fontSize: dataTable.rowtextSize==null?12.0:dataTable.rowtextSize))));
    }
    r.add(DataRow(cells: dc));
  }

  return Container(

    color: dataTable.backgroundColour==null?MediumGreyThemeData().accentColor:dataTable.backgroundColour,
    child: DataTable(
      columns: c,
      rows: r,
      sortAscending: dataTable.sortAscending==null?true:dataTable.sortAscending,
      sortColumnIndex: dataTable.sortColumnIndex==null?0:dataTable.sortColumnIndex,

    ),
  );
}

==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-datatable.dart <==
import 'package:flutter/material.dart';
import 'theme.dart';
import 'widget-classesUsed.dart';


/*
Imports required:
import 'custom-datatable.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';

This widget is used to display a Data Table.
    The view comprises datarows, datacolumns, which in turn comprise of datacells.
    This is a stateless widget.
    The user specifies the headers in the data column, and the data in the datarows.

    SAMPLE IMPLEMENTATION:
    RowColumn row1=new RowColumn(["Ganguly", "38", "Cricketer"]);
    RowColumn row2=new RowColumn(["Messi", "32", "Footballer"]);
    List<RowColumn> rows=[];
    rows.add(row1);
    rows.add(row2);
    RowColumn column = new RowColumn(["name", "age", "Work"]);
    DataTableSchema dt=new DataTableSchema(columns:column,rows:rows, backgroundColour:Colors.white,rowtextColour: Colors.black, rowtextSize: 12.0, columntextColour: Colors.blueAccent,columntextSize: 14.0);


    //implementation
    Center(child: customisedDataTable(dt))

    */

//AUTHOR : Soumyadeep Mitra

//WIDGET FOR DATA TABLE
Widget customisedDataTable(DataTableSchema dataTable) {
  List<DataRow> r = [];
  List<DataCell> dc = [];
  List<DataColumn> c = [];

  for (var value in dataTable.columns.rowcolumn)
    c.add(DataColumn(
      label: Text(
        value,
        style: TextStyle(fontStyle: FontStyle.italic,color: dataTable.columntextColour==null?mediumGreyThemeData().hintColor:dataTable.columntextColour, fontSize:dataTable.columntextSize==null?12.0:dataTable.columntextSize ),
      ),
    ));

  for (var value in dataTable.rows) {
    dc = [];
    for (var value1 in value.rowcolumn) {
      dc.add(DataCell(Text(value1,style: TextStyle(fontStyle: FontStyle.italic,color: dataTable.rowtextColour==null?mediumGreyThemeData().hintColor:dataTable.rowtextColour,fontSize: dataTable.rowtextSize==null?12.0:dataTable.rowtextSize))));
    }
    r.add(DataRow(cells: dc));
  }

  return Container(

    color: dataTable.backgroundColour==null?mediumGreyThemeData().accentColor:dataTable.backgroundColour,
    child: DataTable(
      columns: c,
      rows: r,
      sortAscending: dataTable.sortAscending==null?true:dataTable.sortAscending,
      sortColumnIndex: dataTable.sortColumnIndex==null?0:dataTable.sortColumnIndex,

    ),
  );
}
